==> apache-doris-1.1.5-src.tar.gz: apache-doris-1.1.5-src/docs/zh-CN/community/team.md <==
---
{
    "title": "Doris 团队",
    "language": "zh-CN"
}
---

<!-- 
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# PMC Members & Committer

## Mentors (3)

| Apache ID                                                    | Github 用户名 | 公开名            |
| ------------------------------------------------------------ | ------------- | ----------------- |
| [wenming](https://people.apache.org/committer-index.html#wenming) | moonming      | Ming Wen          |
| [shaofengshi](https://people.apache.org/committer-index.html#shaofengshi) | shaofengshi   | Shao Feng Shi     |
| [ningjiang](https://people.apache.org/committer-index.html#ningjiang) | WillemJiang   | Willem Ning Jiang |

我们要感谢以下提交者，他们帮助Apache Doris (incubating) 取得了今天的进展。此列表可能已过时，正式列表位于 [Apache 的网站上](https://people.apache.org/committers-by-project.html#doris) 。

## PPMC (22)

(如下列表不包含 mentors)

| Apache ID                                                    | Github 用户名       | 公开名        |
| :----------------------------------------------------------- | :------------------ | :------------ |
| [lingbin](https://people.apache.org/committer-index.html#lingbin) | lingbin             | Bin Ling      |
| [wangbo](https://people.apache.org/committer-index.html#wangbo) | wangbo              | Bo Wang       |
| [lichaoyong](https://people.apache.org/committer-index.html#lichaoyong) | chaoyli             | Chaoyong Li   |
| [zhaoc](https://people.apache.org/committer-index.html#zhaoc) | imay                | Chun Zhao     |
| [caiconghui](https://people.apache.org/committer-index.html#caiconghui) | caiconghui          | Conghui Cai   |
| [gaodayue](https://people.apache.org/committer-index.html#gaodayue) | gaodayue            | Dayue Gao     |
| [lide](https://people.apache.org/committer-index.html#lide)  | lide-reed, doris-ci | De Li         |
| [liuhangyuan](https://people.apache.org/committer-index.html#liuhangyuan) | HangyuanLiu         | Hangyuan Liu  |
| [chenhao](https://people.apache.org/committer-index.html#chenhao) | chenhao7253886      | Hao Chen      |
| [kangkaisen](https://people.apache.org/committer-index.html#kangkaisen) | kangkaisen          | Kaisen Kang   |
| [lihaopeng](https://people.apache.org/committer-index.html#lihaopeng) | HappenLee           | Haopeng Li    |
| [jiafengzheng](https://people.apache.org/committer-index.html#jiafengzheng) | hf200012            | Jiafeng Zhang |
| [lingmiao](https://people.apache.org/committer-index.html#lingmiao) | EmmyMiao87          | Ling Miao     |
| [morningman](https://people.apache.org/committer-index.html#morningman) | morningman          | Mingyu Chen   |
| [maruyue](https://people.apache.org/committer-index.html#maruyue) |                     | Ruyue Ma      |
| [sijie](https://people.apache.org/committer-index.html#sijie) | sijie               | Sijie Guo     |
| [zshao](https://people.apache.org/committer-index.html#zshao) | zshao               | Zheng Shao    |
| [yangzhg](https://people.apache.org/committer-index.html#yangzhg) | yangzhg             | Zhengguo Yang |
| [weizuo](https://people.apache.org/committer-index.html#weizuo) | weizuo93            | Zuo Wei       |

## Committers (33)

(如下列表不包含上述 PPMC 成员)

| Apache ID                                                    | Github 用户名    | 公开名         |
| :----------------------------------------------------------- | :--------------- | :------------- |
| [diwu](https://people.apache.org/committer-index.html#diwu)  | JNSimba          | Di Wu          |
| [yiguolei](https://people.apache.org/committer-index.html#yiguolei) | yiguolei         | Guolei Yi      |
| [huajianlan](https://people.apache.org/committer-index.html#huajianlan) | 924060929        | Huajian Lan    |
| [huangwei](https://people.apache.org/committer-index.html#huangwei) | vagetablechicken | Huang Wei      |
| [jianliangqi](https://people.apache.org/committer-index.html#jianliangqi) | qidaye           | Jianliang Qi   |
| [kangpinghuang](https://people.apache.org/committer-index.html#kangpinghuang) | kangpinghuang    | Kangping Huang |
| [liulijia](https://people.apache.org/committer-index.html#liulijia) | liutang123       | Lijia Liu      |
| [wangxixu](https://people.apache.org/committer-index.html#wangxixu) | xinghuayu007     | Xixu Wang      |
| [xuyang](https://people.apache.org/committer-index.html#xuyang) | xy720            | Yang Xu        |
| [laiyingchun](https://people.apache.org/committer-index.html#laiyingchun) | acelyc111        | Yingchun Lai   |
| [wyf](https://people.apache.org/committer-index.html#wyf)    | wuyunfeng        | Yunfeng Wu     |
| [weizuo](https://people.apache.org/committer-index.html#weizuo) | weizuo93         | Zuo Wei        |

## Contributor

[All Contributors](https://github.com/apache/incubator-doris/graphs/contributors)

==> apache-doris-2.0.1-rc04-src.tar.gz: apache-doris-2.0.1-src/docs/zh-CN/community/team.md <==
---
{
    "title": "Doris 团队",
    "language": "zh-CN"
}
---

<!-- 
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# PMC Members & Committers

我们要感谢以下提交者，他们帮助Apache Doris 取得了今天的进展。此列表可能已过时，正式列表位于 [Apache 的网站上](https://people.apache.org/committers-by-project.html#doris) 。

## PMC (17)

| Apache ID                                                    | Github 用户名       | 公开名        |
| :----------------------------------------------------------- | :------------------ | :------------ |
| [lingbin](https://people.apache.org/committer-index.html#lingbin) | lingbin             | Bin Ling      |
| [wangbo](https://people.apache.org/committer-index.html#wangbo) | wangbo              | Bo Wang       |
| [caiconghui](https://people.apache.org/committer-index.html#caiconghui) | caiconghui          | Conghui Cai   |
| [gaodayue](https://people.apache.org/committer-index.html#gaodayue) | gaodayue            | Dayue Gao     |
| [lide](https://people.apache.org/committer-index.html#lide)  | lide-reed, doris-ci | De Li         |
| [yiguolei](https://people.apache.org/committer-index.html#yiguolei) | yiguolei         | Guolei Yi      |
| [chenhao](https://people.apache.org/committer-index.html#chenhao) | chenhao7253886      | Hao Chen      |
| [lihaopeng](https://people.apache.org/committer-index.html#lihaopeng) | HappenLee           | Haopeng Li    |
| [jiafengzheng](https://people.apache.org/committer-index.html#jiafengzheng) | hf200012            | Jiafeng Zhang |
| [lingmiao](https://people.apache.org/committer-index.html#lingmiao) | EmmyMiao87          | Ling Miao     |
| [wenming](https://people.apache.org/committer-index.html#wenming) | moonming      | Ming Wen          |
| [morningman](https://people.apache.org/committer-index.html#morningman) | morningman          | Mingyu Chen   |
| [maruyue](https://people.apache.org/committer-index.html#maruyue) | maruyue                    | Ruyue Ma      |
| [ningjiang](https://people.apache.org/committer-index.html#ningjiang) | WillemJiang   | Willem Ning Jiang |
| [dataroaring](https://people.apache.org/committer-index.html#dataroaring) | dataroaring | Yongqiang Yang   |
| [yangzhg](https://people.apache.org/committer-index.html#yangzhg) | yangzhg             | Zhengguo Yang |
| [weizuo](https://people.apache.org/committer-index.html#weizuo) | weizuo93            | Zuo Wei       |

## Committers (52)

(如下列表不包含上述 PMC 成员)

| Apache ID                                                    | Github 用户名    | 公开名         |
| :----------------------------------------------------------- | :--------------- | :------------- |
| [lichaoyong](https://people.apache.org/committer-index.html#lichaoyong) | chaoyli             | Chaoyong Li   |
| [starocean999](https://people.apache.org/committer-index.html#starocean999)    | starocean999 | Chi Li |
| [zhangchen](https://people.apache.org/committer-index.html#zhangchen) | zhannngchen                | Chen Zhang     |
| [zhaoc](https://people.apache.org/committer-index.html#zhaoc) | imay                | Chun Zhao     |
| [adonisling](https://people.apache.org/committer-index.html#adonisling) | adonis0147             | Cong Ling   |
| [diwu](https://people.apache.org/committer-index.html#diwu)  | JNSimba          | Di Wu          |
| [liuhangyuan](https://people.apache.org/committer-index.html#liuhangyuan) | HangyuanLiu         | Hangyuan Liu  |
| [huajianlan](https://people.apache.org/committer-index.html#huajianlan) | 924060929        | Huajian Lan    |
| [huangwei](https://people.apache.org/committer-index.html#huangwei) | vagetablechicken | Huang Wei      |
| [jianliangqi](https://people.apache.org/committer-index.html#jianliangqi) | qidaye           | Jianliang Qi   |
| [jakevin](https://people.apache.org/committer-index.html#jakevin)    | jackwener | Jie Wen |
| [kangkaisen](https://people.apache.org/committer-index.html#kangkaisen) | kangkaisen          | Kaisen Kang   |
| [kangpinghuang](https://people.apache.org/committer-index.html#kangpinghuang) | kangpinghuang    | Kangping Huang |
| [liulijia](https://people.apache.org/committer-index.html#liulijia) | liutang123       | Lijia Liu      |
| [linzhongcheng](https://people.apache.org/committer-index.html#linzhongcheng) | chenlinzhong       | LinZhong Chen      |
| [stalary](https://people.apache.org/committer-index.html#stalary)    | stalary | Rongqian Li |
| [shaofengshi](https://people.apache.org/committer-index.html#shaofengshi) | shaofengshi     | Shaofeng Shi     |
| [sijie](https://people.apache.org/committer-index.html#sijie) | sijie               | Sijie Guo     |
| [yintao](https://people.apache.org/committer-index.html#yintao) | yinzhijian               | Tao Yin    |
| [gabriellee](https://people.apache.org/committer-index.html#gabriellee)    | Gabriel39 | Wenqiang Li |
| [morrysnow](https://people.apache.org/committer-index.html#morrysnow)    | morrySnow  | Wenxin Zhang |
| [panxiaolei](https://people.apache.org/committer-index.html#panxiaolei) | BiteTheDDDDt       | Xiaolei Pan      |
| [cambyzju](https://people.apache.org/committer-index.html#cambyzju)    | cambyzju | Xiaoli Zhu  |
| [pengxiangyu](https://people.apache.org/committer-index.html#pengxiangyu)    | pengxiangyu | Xiangyu Peng |
| [weixiang](https://people.apache.org/committer-index.html#weixiang) | spaces-X            | Xiang Wei     |
| [zouxinyi](https://people.apache.org/committer-index.html#zouxinyi) | xinyiZzz               | Xinyi Zou     |
| [wangxixu](https://people.apache.org/committer-index.html#wangxixu) | xinghuayu007     | Xixu Wang      |
| [xuyang](https://people.apache.org/committer-index.html#xuyang) | xy720            | Yang Xu        |
| [laiyingchun](https://people.apache.org/committer-index.html#laiyingchun) | acelyc111        | Yingchun Lai   |
| [wyf](https://people.apache.org/committer-index.html#wyf)    | wuyunfeng        | Yunfeng Wu     |
| [luozenglin](https://people.apache.org/committer-index.html#luozenglin)    | luozenglin | Zenglin Luo |
| [zenoyang](https://people.apache.org/committer-index.html#zenoyang)    | zenoyang  | Zeno Yang     |
| [zshao](https://people.apache.org/committer-index.html#zshao)    | zshao | Zheng Shao |
| [luzhijing](https://people.apache.org/committer-index.html#luzhijing)    | luzhijing | Zhijing Lu |
| [englefly](https://people.apache.org/committer-index.html#englefly)    | englefly | Zhou Minghong |

## Contributors

[All Contributors](https://github.com/apache/doris/graphs/contributors)
